===========
whatsonpypi
===========


.. image:: https://img.shields.io/pypi/v/whatsonpypi.svg
        :target: https://pypi.python.org/pypi/whatsonpypi

.. image:: https://img.shields.io/travis/viseshrp/whatsonpypi.svg
        :target: https://travis-ci.org/viseshrp/whatsonpypi

.. image:: https://readthedocs.org/projects/whatsonpypi/badge/?version=latest
        :target: https://whatsonpypi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pepy.tech/badge/whatsonpypi
        :target: https://pepy.tech/project/whatsonpypi
        :alt: Downloads


CLI tool to find package info on PyPI


* GitHub: https://github.com/viseshrp/whatsonpypi
* PyPI: https://pypi.python.org/pypi/whatsonpypi
* Free software: MIT license
* Documentation: https://whatsonpypi.readthedocs.io.


Installation
------------
.. code-block:: bash

    pip install whatsonpypi


Requirements
------------

#. Python 3.6+


Features
--------

* Find the latest version of a package on PyPI

Examples:

.. code-block:: bash

    $ whatsonpypi django
    2.1.4

* More to come ..


Credits
-------

* Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template for getting me started.


.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

